Introduction
============

This role allows management of custom file paths, file contents and archives on
remote hosts without the need to create a separate Ansible role. You can use
inventory lists to define what files to copy, what directories should exist on
a remote host, what online resources to download, and so on.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.0.0``. To install it, run::

    ansible-galaxy install debops.resources

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
